@@ -41,7 +41,7 @@ class SqlClient(NamespacedClient):
         """
         Clears the SQL cursor
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/clear-sql-cursor-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/clear-sql-cursor-api.html>`_
 
         :param cursor:
         """
@@ -81,7 +81,7 @@ class SqlClient(NamespacedClient):
         Deletes an async SQL search or a stored synchronous SQL search. If the search
         is still running, the API cancels it.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/delete-async-sql-search-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/delete-async-sql-search-api.html>`_
 
         :param id: The async search ID
         """
@@ -114,15 +114,17 @@ class SqlClient(NamespacedClient):
         ] = None,
         format: t.Optional[str] = None,
         human: t.Optional[bool] = None,
-        keep_alive: t.Optional[t.Union[int, str]] = None,
+        keep_alive: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
         pretty: t.Optional[bool] = None,
-        wait_for_completion_timeout: t.Optional[t.Union[int, str]] = None,
+        wait_for_completion_timeout: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Returns the current status and available results for an async SQL search or stored
         synchronous SQL search
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/get-async-sql-search-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/get-async-sql-search-api.html>`_
 
         :param id: The async search ID
         :param delimiter: Separator for CSV results. The API only supports this parameter
@@ -176,7 +178,7 @@ class SqlClient(NamespacedClient):
         Returns the current status of an async SQL search or a stored synchronous SQL
         search
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/get-async-sql-search-status-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/get-async-sql-search-status-api.html>`_
 
         :param id: The async search ID
         """
@@ -217,13 +219,15 @@ class SqlClient(NamespacedClient):
         format: t.Optional[str] = None,
         human: t.Optional[bool] = None,
         index_using_frozen: t.Optional[bool] = None,
-        keep_alive: t.Optional[t.Union[int, str]] = None,
+        keep_alive: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
         keep_on_completion: t.Optional[bool] = None,
-        page_timeout: t.Optional[t.Union[int, str]] = None,
+        page_timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
         params: t.Optional[t.Mapping[str, t.Any]] = None,
         pretty: t.Optional[bool] = None,
         query: t.Optional[str] = None,
-        request_timeout: t.Optional[t.Union[int, str]] = None,
+        request_timeout: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
         runtime_mappings: t.Optional[
             t.Mapping[
                 str,
@@ -237,12 +241,14 @@ class SqlClient(NamespacedClient):
             ]
         ] = None,
         time_zone: t.Optional[str] = None,
-        wait_for_completion_timeout: t.Optional[t.Union[int, str]] = None,
+        wait_for_completion_timeout: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Executes a SQL request
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/sql-search-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/sql-search-api.html>`_
 
         :param catalog: Default catalog (cluster) for queries. If unspecified, the queries
             execute on the data in the local cluster only.
@@ -343,7 +349,7 @@ class SqlClient(NamespacedClient):
         """
         Translates SQL into Elasticsearch queries
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/sql-translate-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/sql-translate-api.html>`_
 
         :param query:
         :param fetch_size:
