@@ -45,7 +45,7 @@ class TasksClient(NamespacedClient):
         """
         Cancels a task, if it can be cancelled through an API.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/tasks.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/tasks.html>`_
 
         :param task_id: Cancel the task with specified task id (node_id:task_number)
         :param actions: A comma-separated list of actions that should be cancelled. Leave
@@ -95,13 +95,13 @@ class TasksClient(NamespacedClient):
         ] = None,
         human: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union[int, str]] = None,
+        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
         wait_for_completion: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Returns information about a task.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/tasks.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/tasks.html>`_
 
         :param task_id: Return the task with specified id (node_id:task_number)
         :param timeout: Explicit operation timeout
@@ -145,17 +145,19 @@ class TasksClient(NamespacedClient):
             t.Union["t.Literal['nodes', 'none', 'parents']", str]
         ] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[t.Union[int, str]] = None,
+        master_timeout: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
         node_id: t.Optional[t.Union[t.List[str], t.Tuple[str, ...]]] = None,
         parent_task_id: t.Optional[str] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union[int, str]] = None,
+        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
         wait_for_completion: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Returns a list of tasks.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/tasks.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/tasks.html>`_
 
         :param actions: Comma-separated list or wildcard expression of actions used to
             limit the request.
